getFeatures: Gets all singular features from a systemic functional network...

Description Usage Arguments Value

View source: R/getFeatures.R

Description

This function gets all the features from input systems. Since input systems are complex in their structure, this functions clears opositions and lower delicacy levels. It requires 'stringr' library

Usage

1
getFeatures(df, coselection = FALSE)

Arguments

df

The dataframe with a initial column named 'features'.

Value

The features of each complex system structure in the 'features' column


bmmedinac/gleasonCalc documentation built on Dec. 31, 2020, 8:56 p.m.